@@ -1,8 +1,9 @@
 from urllib.parse import urlparse
 
+import math
 from elasticsearch import Elasticsearch
 
-from politylink.elasticsearch.schema import NewsText, BillText, MinutesText, AbstractText
+from politylink.elasticsearch.schema import AbstractText, to_cls
 
 
 class ElasticsearchException(Exception):
@@ -38,12 +39,7 @@ class ElasticsearchClient:
         """
 
         try:
-            if id_.startswith('News'):
-                cls = NewsText
-            elif id_.startswith('Bill'):
-                cls = BillText
-            elif id_.startswith('Minutes'):
-                cls = MinutesText
+            cls = to_cls(id_)
             res = self.client.get(index=cls.index, id=id_)
             return cls(res['_source'])
         except Exception as e:
@@ -63,4 +59,28 @@ class ElasticsearchClient:
             res = self.client.search(index=cls.index, body=query_doc)
             return list(map(lambda hit: cls(hit['_source']), res['hits']['hits']))
         except Exception as e:
-            raise ElasticsearchException(f'failed to search NewsText for {query_doc}') from e
+            raise ElasticsearchException(f'failed to search {cls.__class__.__name__} for {query_doc}') from e
+
+    def get_term_statistics(self, id_):
+        """
+        get term statistics using termvectors API
+
+        :param id_: politylink ID
+        :return: dictionary of term to statistics (tf, idf, tfidf)
+        """
+
+        try:
+            cls = to_cls(id_)
+            res = self.client.termvectors(index=cls.index, id=id_, params={'fields': 'body', 'term_statistics': 'true'})
+        except Exception as e:
+            raise ElasticsearchException(f'failed to get termvectors for {id_}') from e
+
+        term2stats = dict()
+        doc_count = res['term_vectors']['body']['field_statistics']['doc_count']
+        for term, stats_raw in res['term_vectors']['body']['terms'].items():
+            stats = dict()
+            stats['tf'] = stats_raw['term_freq']
+            stats['idf'] = math.log(doc_count / stats_raw['doc_freq'])
+            stats['tfidf'] = stats['tf'] * stats['idf']
+            term2stats[term] = stats
+        return term2stats
